.. _supported_files:

Supported files
===============

.. toctree::
   :maxdepth: 1
   :caption: Supported files:

   gridadmin
   results
   aggregate_results
   structure_control
   water_quality_results